You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kylin.apache.org by li...@apache.org on 2016/09/03 06:37:34 UTC

[27/50] [abbrv] kylin git commit: minor use 'unset' to clear sys variable

minor use 'unset' to clear sys variable


Project: http://git-wip-us.apache.org/repos/asf/kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/kylin/commit/42f28688
Tree: http://git-wip-us.apache.org/repos/asf/kylin/tree/42f28688
Diff: http://git-wip-us.apache.org/repos/asf/kylin/diff/42f28688

Branch: refs/heads/1.5.x-HBase1.x
Commit: 42f286884598aac3e8d8a63c4462f6ead74bd8c2
Parents: 6c23313
Author: shaofengshi <sh...@apache.org>
Authored: Tue Aug 30 20:43:32 2016 +0800
Committer: shaofengshi <sh...@apache.org>
Committed: Tue Aug 30 20:43:32 2016 +0800

----------------------------------------------------------------------
 build/bin/kylin.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/kylin/blob/42f28688/build/bin/kylin.sh
----------------------------------------------------------------------
diff --git a/build/bin/kylin.sh b/build/bin/kylin.sh
index 695b7f6..201b5b6 100644
--- a/build/bin/kylin.sh
+++ b/build/bin/kylin.sh
@@ -213,7 +213,7 @@ then
     retrieveDependency
 
     #retrive $KYLIN_EXTRA_START_OPTS from a separate file called setenv-tool.sh
-    reset KYLIN_EXTRA_START_OPTS # reset the global server setenv config first
+    unset KYLIN_EXTRA_START_OPTS # unset the global server setenv config first
     if [ -f "${dir}/setenv-tool.sh" ]
         then source ${dir}/setenv-tool.sh
     fi